aboutsummaryrefslogtreecommitdiff
path: root/lib/hostip.h
diff options
context:
space:
mode:
authorDaniel Stenberg <daniel@haxx.se>2005-02-09 13:06:40 +0000
committerDaniel Stenberg <daniel@haxx.se>2005-02-09 13:06:40 +0000
commit6a2e21ec8cbaf7c719902e06953d9dbec629ad4f (patch)
treec09552b516d0d6dadc999ef446843ba32db4f1e1 /lib/hostip.h
parent120f17ce04794f55603a1edcd8ec8f89a09fe4ca (diff)
FTP code turned into state machine. Not completely yet, but a good start.
The tag 'before_ftp_statemachine' was set just before this commit in case of future need.
Diffstat (limited to 'lib/hostip.h')
-rw-r--r--lib/hostip.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/hostip.h b/lib/hostip.h
index 4fd03c1af..0b06bae6a 100644
--- a/lib/hostip.h
+++ b/lib/hostip.h
@@ -159,13 +159,13 @@ CURLcode Curl_is_resolved(struct connectdata *conn,
CURLcode Curl_wait_for_resolv(struct connectdata *conn,
struct Curl_dns_entry **dnsentry);
/* Curl_fdset() is a generic function that exists in multiple versions
depending on what name resolve technology we've built to use. The function
is called from the curl_multi_fdset() function */
-CURLcode Curl_fdset(struct connectdata *conn,
- fd_set *read_fd_set,
- fd_set *write_fd_set,
- int *max_fdp);
+CURLcode Curl_resolv_fdset(struct connectdata *conn,
+ fd_set *read_fd_set,
+ fd_set *write_fd_set,
+ int *max_fdp);
/* unlock a previously resolved dns entry */
void Curl_resolv_unlock(struct SessionHandle *data, struct Curl_dns_entry *dns);
@@ -159,13 +159,13 @@ CURLcode Curl_is_resolved(struct connectdata *conn,
CURLcode Curl_wait_for_resolv(struct connectdata *conn,
struct Curl_dns_entry **dnsentry);
-/* Curl_fdset() is a generic function that exists in multiple versions
+/* Curl_resolv_fdset() is a generic function that exists in multiple versions
depending on what name resolve technology we've built to use. The function
is called from the curl_multi_fdset() function */